@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_datapipeline import DataPipelineClient
 
-    session = boto3.Session()
-
     client: DataPipelineClient = boto3.client("datapipeline")
-    session_client: DataPipelineClient = session.client("datapipeline")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
