@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_datapipeline import DataPipelineClient
-    from mypy_boto3_datapipeline import (
+    from mypy_boto3_datapipeline.paginator import (
         DescribeObjectsPaginator,
         ListPipelinesPaginator,
         QueryObjectsPaginator,
